@@ -27,15 +27,16 @@ class AzImport:
     def __init__(self, ast_node):
         self.node = ast_node
         self.error = None
+        self.level = None
 
         if isinstance(ast_node, ast.Import):
             self.is_import = True
             names = ast_node.names
             if len(names) != 1:
-                self.error = "pep8"
                 return
 
             self.module_name = names[0].name
+            self.level = 0
 
         elif isinstance(ast_node, ast.ImportFrom):
             self.is_import = False
@@ -50,6 +51,7 @@ class AzImport:
                     f"Imported names are in the wrong order. Should be "
                     f"{', '.join(expected_names)}",
                 )
+            self.level = ast_node.level
 
         else:
             raise AlphabetizeException(f"Node type {type(ast_node)} not recognized")
@@ -60,32 +62,61 @@ class AzImport:
         return self.node == other.node
 
     def __lt__(self, other):
-        return self.module_name < other.module_name
+        if self.in_stdlib == other.in_stdlib:
+            if self.level == other.level:
+                return self.module_name < other.module_name
+            else:
+                return self.level < other.level
+        else:
+            return self.in_stdlib > other.in_stdlib
 
     def __str__(self):
         if self.is_import:
             return f"import {self.module_name}"
         else:
+            level = self.node.level
+            level_str = "" if level == 0 else "." * level
             names = [
                 n.name + ("" if n.asname is None else f" as {n.asname}")
                 for n in self.node.names
             ]
-            return f"from {self.node.module} import {', '.join(names)}"
+            return f"from {level_str}{self.node.module} import {', '.join(names)}"
+
+
+IMPORT_TYPES = ast.Import, ast.ImportFrom
 
 
 def _find_imports(tree):
-    return [n for n in ast.walk(tree) if isinstance(n, (ast.Import, ast.ImportFrom))]
+    if isinstance(tree, ast.Module):
+        body = tree.body
+        if isinstance(body, IMPORT_TYPES):
+            return [body]
+        elif isinstance(body, list):
+            return [n for n in body if isinstance(n, IMPORT_TYPES)]
+        else:
+            return []
 
 
 def _find_errors(tree):
     imports = [AzImport(imp) for imp in _find_imports(tree)]
     errors = []
 
-    if len(imports) < 2:
+    len_imports = len(imports)
+    if len_imports == 0:
         return errors
 
     p = imports[0]
+    if p.error is not None:
+        errors.append(p.error)
+
+    if len_imports < 2:
+        return errors
+
     for n in imports[1:]:
+
+        if n.error is not None:
+            errors.append(n.error)
+
         if n < p:
             errors.append(
                 _make_error(
